# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from Vpsa.api_client import ApiClient


class LogsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_logs(self, **kwargs):  # noqa: E501
        """get_logs  # noqa: E501

        Retrieve event logs.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_logs(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int severity:
        :param str attr_key:
        :param str attr_value:
        :param int start: The item number to start from. 0 starts from the beginning.
        :param int limit: The total number of records to return.
        :return: InlineResponse20051
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_logs_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_logs_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_logs_with_http_info(self, **kwargs):  # noqa: E501
        """get_logs  # noqa: E501

        Retrieve event logs.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_logs_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int severity:
        :param str attr_key:
        :param str attr_value:
        :param int start: The item number to start from. 0 starts from the beginning.
        :param int limit: The total number of records to return.
        :return: InlineResponse20051
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['severity', 'attr_key', 'attr_value', 'start', 'limit']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_logs" % key
                )
            params[key] = val
        del params['kwargs']

        if self.api_client.client_side_validation and ('start' in params and params['start'] < 0):  # noqa: E501
            raise ValueError("Invalid value for parameter `start` when calling `get_logs`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'severity' in params:
            query_params.append(('severity', params['severity']))  # noqa: E501
        if 'attr_key' in params:
            query_params.append(('attr_key', params['attr_key']))  # noqa: E501
        if 'attr_value' in params:
            query_params.append(('attr_value', params['attr_value']))  # noqa: E501
        if 'start' in params:
            query_params.append(('start', params['start']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/messages.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20051',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class InlineResponse20082ResponseVolumes(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'display_name': 'str',
        'cg_display_name': 'str',
        'cg_name': 'str',
        'cg_user_created': 'str',
        'pool_display_name': 'str',
        'pool_name': 'str',
        'pool_version': 'int',
        'status': 'str',
        'virtual_capacity': 'int',
        'server_name': 'str',
        'av_scan_policy_name': 'str',
        'provisioned_capacity': 'int',
        'server_ext_names': 'str',
        'life_cycle_policy_display_name': 'str',
        'life_cycle_policy_ext_name': 'str',
        'thin': 'str',
        'encryption': 'str',
        'encryption_key_size': 'str',
        'total_capacity': 'float',
        'available_capacity': 'float',
        'num_of_filesystem_objects': 'int',
        'capacity_mode': 'str',
        'allocated_capacity': 'float',
        'data_copies_capacity': 'float',
        'access_type': 'str',
        'read_only': 'str',
        'nfs_export_path': 'str',
        'smb_export_path': 'str',
        'additional_smb_export_paths_count': 'int',
        'mount_sync': 'str',
        'atime_update': 'str',
        'read_ahead_kb': 'int',
        'ext_metering': 'str',
        'images_repo': 'str',
        'flc_db': 'str',
        'quarantine_repo': 'str',
        'audit_repo': 'str',
        'nfs_root_squash': 'str',
        'nfs_all_squash': 'str',
        'nfs_anon_uid': 'str',
        'nfs_anon_gid': 'str',
        'smb_only': 'str',
        'smb_guest': 'str',
        'smb_windows_acl': 'str',
        'smb_map_archive': 'str',
        'smb_file_create_mask': 'str',
        'smb_dir_create_mask': 'str',
        'smb_aio_size': 'int',
        'smb_browseable': 'str',
        'smb_hidden_files': 'str',
        'smb_encryption_mode': 'str',
        'smb_case_sensitive': 'str',
        'smb_mangled_names': 'str',
        'smb_hide_unreadable': 'str',
        'smb_hide_unwriteable': 'str',
        'smb_hide_dot_files': 'str',
        'smb_store_dos_attributes': 'str',
        'smb_enable_oplocks': 'str',
        'audit_enable': 'str',
        'capacity_history': 'int',
        'alert_mode': 'int',
        'emergency_mode_mb': 'int',
        'auto_expand_on_emergency': 'str',
        'auto_expand_by': 'int',
        'max_capacity': 'int',
        'uquota_state': 'str',
        'gquota_state': 'str',
        'pquota_state': 'str',
        'target': 'str',
        'lun': 'str',
        'cache': 'str',
        'tenant_id': 'int',
        'has_mirror': 'str',
        'has_backup': 'str',
        'is_remote_clone_source': 'str',
        'has_snapshots': 'str',
        'shadow_copy_enabled': 'str',
        'is_shadow_copy_clone': 'str',
        'read_iops_limit': 'str',
        'read_mbps_limit': 'str',
        'write_iops_limit': 'str',
        'write_mbps_limit': 'str',
        'read_iops_capping': 'str',
        'read_mbps_capping': 'str',
        'write_iops_capping': 'str',
        'write_mbps_capping': 'str',
        'compress': 'str',
        'dedupe': 'str',
        'mtr_histograms': 'str',
        'flc_state': 'str',
        'flc_scan_state': 'str',
        'flc_scan_progress': 'float',
        'flc_scan_remaining_time_seconds': 'int',
        'thresholds': 'str',
        'comment': 'str',
        'created_at': 'str',
        'modified_at': 'str',
        'data_type': 'str',
        'flc_policy_name': 'str'
    }

    attribute_map = {
        'name': 'name',
        'display_name': 'display_name',
        'cg_display_name': 'cg_display_name',
        'cg_name': 'cg_name',
        'cg_user_created': 'cg_user_created',
        'pool_display_name': 'pool_display_name',
        'pool_name': 'pool_name',
        'pool_version': 'pool_version',
        'status': 'status',
        'virtual_capacity': 'virtual_capacity',
        'server_name': 'server_name',
        'av_scan_policy_name': 'av_scan_policy_name',
        'provisioned_capacity': 'provisioned_capacity',
        'server_ext_names': 'server_ext_names',
        'life_cycle_policy_display_name': 'life_cycle_policy_display_name',
        'life_cycle_policy_ext_name': 'life_cycle_policy_ext_name',
        'thin': 'thin',
        'encryption': 'encryption',
        'encryption_key_size': 'encryption_key_size',
        'total_capacity': 'total_capacity',
        'available_capacity': 'available_capacity',
        'num_of_filesystem_objects': 'num_of_filesystem_objects',
        'capacity_mode': 'capacity_mode',
        'allocated_capacity': 'allocated_capacity',
        'data_copies_capacity': 'data_copies_capacity',
        'access_type': 'access_type',
        'read_only': 'read_only',
        'nfs_export_path': 'nfs_export_path',
        'smb_export_path': 'smb_export_path',
        'additional_smb_export_paths_count': 'additional_smb_export_paths_count',
        'mount_sync': 'mount_sync',
        'atime_update': 'atime_update',
        'read_ahead_kb': 'read_ahead_kb',
        'ext_metering': 'ext_metering',
        'images_repo': 'images_repo',
        'flc_db': 'flc_db',
        'quarantine_repo': 'quarantine_repo',
        'audit_repo': 'audit_repo',
        'nfs_root_squash': 'nfs_root_squash',
        'nfs_all_squash': 'nfs_all_squash',
        'nfs_anon_uid': 'nfs_anon_uid',
        'nfs_anon_gid': 'nfs_anon_gid',
        'smb_only': 'smb_only',
        'smb_guest': 'smb_guest',
        'smb_windows_acl': 'smb_windows_acl',
        'smb_map_archive': 'smb_map_archive',
        'smb_file_create_mask': 'smb_file_create_mask',
        'smb_dir_create_mask': 'smb_dir_create_mask',
        'smb_aio_size': 'smb_aio_size',
        'smb_browseable': 'smb_browseable',
        'smb_hidden_files': 'smb_hidden_files',
        'smb_encryption_mode': 'smb_encryption_mode',
        'smb_case_sensitive': 'smb_case_sensitive',
        'smb_mangled_names': 'smb_mangled_names',
        'smb_hide_unreadable': 'smb_hide_unreadable',
        'smb_hide_unwriteable': 'smb_hide_unwriteable',
        'smb_hide_dot_files': 'smb_hide_dot_files',
        'smb_store_dos_attributes': 'smb_store_dos_attributes',
        'smb_enable_oplocks': 'smb_enable_oplocks',
        'audit_enable': 'audit_enable',
        'capacity_history': 'capacity_history',
        'alert_mode': 'alert_mode',
        'emergency_mode_mb': 'emergency_mode_mb',
        'auto_expand_on_emergency': 'auto_expand_on_emergency',
        'auto_expand_by': 'auto_expand_by',
        'max_capacity': 'max_capacity',
        'uquota_state': 'uquota_state',
        'gquota_state': 'gquota_state',
        'pquota_state': 'pquota_state',
        'target': 'target',
        'lun': 'lun',
        'cache': 'cache',
        'tenant_id': 'tenant_id',
        'has_mirror': 'has_mirror',
        'has_backup': 'has_backup',
        'is_remote_clone_source': 'is_remote_clone_source',
        'has_snapshots': 'has_snapshots',
        'shadow_copy_enabled': 'shadow_copy_enabled',
        'is_shadow_copy_clone': 'is_shadow_copy_clone',
        'read_iops_limit': 'read_iops_limit',
        'read_mbps_limit': 'read_mbps_limit',
        'write_iops_limit': 'write_iops_limit',
        'write_mbps_limit': 'write_mbps_limit',
        'read_iops_capping': 'read_iops_capping',
        'read_mbps_capping': 'read_mbps_capping',
        'write_iops_capping': 'write_iops_capping',
        'write_mbps_capping': 'write_mbps_capping',
        'compress': 'compress',
        'dedupe': 'dedupe',
        'mtr_histograms': 'mtr_histograms',
        'flc_state': 'flc_state',
        'flc_scan_state': 'flc_scan_state',
        'flc_scan_progress': 'flc_scan_progress',
        'flc_scan_remaining_time_seconds': 'flc_scan_remaining_time_seconds',
        'thresholds': 'thresholds',
        'comment': 'comment',
        'created_at': 'created_at',
        'modified_at': 'modified_at',
        'data_type': 'data_type',
        'flc_policy_name': 'flc_policy_name'
    }

    def __init__(self, name=None, display_name=None, cg_display_name=None, cg_name=None, cg_user_created=None, pool_display_name=None, pool_name=None, pool_version=None, status=None, virtual_capacity=None, server_name=None, av_scan_policy_name=None, provisioned_capacity=None, server_ext_names=None, life_cycle_policy_display_name=None, life_cycle_policy_ext_name=None, thin=None, encryption=None, encryption_key_size=None, total_capacity=None, available_capacity=None, num_of_filesystem_objects=None, capacity_mode=None, allocated_capacity=None, data_copies_capacity=None, access_type=None, read_only=None, nfs_export_path=None, smb_export_path=None, additional_smb_export_paths_count=None, mount_sync=None, atime_update=None, read_ahead_kb=None, ext_metering=None, images_repo=None, flc_db=None, quarantine_repo=None, audit_repo=None, nfs_root_squash=None, nfs_all_squash=None, nfs_anon_uid=None, nfs_anon_gid=None, smb_only=None, smb_guest=None, smb_windows_acl=None, smb_map_archive=None, smb_file_create_mask=None, smb_dir_create_mask=None, smb_aio_size=None, smb_browseable=None, smb_hidden_files=None, smb_encryption_mode=None, smb_case_sensitive=None, smb_mangled_names=None, smb_hide_unreadable=None, smb_hide_unwriteable=None, smb_hide_dot_files=None, smb_store_dos_attributes=None, smb_enable_oplocks=None, audit_enable=None, capacity_history=None, alert_mode=None, emergency_mode_mb=None, auto_expand_on_emergency=None, auto_expand_by=None, max_capacity=None, uquota_state=None, gquota_state=None, pquota_state=None, target=None, lun=None, cache=None, tenant_id=None, has_mirror=None, has_backup=None, is_remote_clone_source=None, has_snapshots=None, shadow_copy_enabled=None, is_shadow_copy_clone=None, read_iops_limit=None, read_mbps_limit=None, write_iops_limit=None, write_mbps_limit=None, read_iops_capping=None, read_mbps_capping=None, write_iops_capping=None, write_mbps_capping=None, compress=None, dedupe=None, mtr_histograms=None, flc_state=None, flc_scan_state=None, flc_scan_progress=None, flc_scan_remaining_time_seconds=None, thresholds=None, comment=None, created_at=None, modified_at=None, data_type=None, flc_policy_name=None, _configuration=None):  # noqa: E501
        """InlineResponse20082ResponseVolumes - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._display_name = None
        self._cg_display_name = None
        self._cg_name = None
        self._cg_user_created = None
        self._pool_display_name = None
        self._pool_name = None
        self._pool_version = None
        self._status = None
        self._virtual_capacity = None
        self._server_name = None
        self._av_scan_policy_name = None
        self._provisioned_capacity = None
        self._server_ext_names = None
        self._life_cycle_policy_display_name = None
        self._life_cycle_policy_ext_name = None
        self._thin = None
        self._encryption = None
        self._encryption_key_size = None
        self._total_capacity = None
        self._available_capacity = None
        self._num_of_filesystem_objects = None
        self._capacity_mode = None
        self._allocated_capacity = None
        self._data_copies_capacity = None
        self._access_type = None
        self._read_only = None
        self._nfs_export_path = None
        self._smb_export_path = None
        self._additional_smb_export_paths_count = None
        self._mount_sync = None
        self._atime_update = None
        self._read_ahead_kb = None
        self._ext_metering = None
        self._images_repo = None
        self._flc_db = None
        self._quarantine_repo = None
        self._audit_repo = None
        self._nfs_root_squash = None
        self._nfs_all_squash = None
        self._nfs_anon_uid = None
        self._nfs_anon_gid = None
        self._smb_only = None
        self._smb_guest = None
        self._smb_windows_acl = None
        self._smb_map_archive = None
        self._smb_file_create_mask = None
        self._smb_dir_create_mask = None
        self._smb_aio_size = None
        self._smb_browseable = None
        self._smb_hidden_files = None
        self._smb_encryption_mode = None
        self._smb_case_sensitive = None
        self._smb_mangled_names = None
        self._smb_hide_unreadable = None
        self._smb_hide_unwriteable = None
        self._smb_hide_dot_files = None
        self._smb_store_dos_attributes = None
        self._smb_enable_oplocks = None
        self._audit_enable = None
        self._capacity_history = None
        self._alert_mode = None
        self._emergency_mode_mb = None
        self._auto_expand_on_emergency = None
        self._auto_expand_by = None
        self._max_capacity = None
        self._uquota_state = None
        self._gquota_state = None
        self._pquota_state = None
        self._target = None
        self._lun = None
        self._cache = None
        self._tenant_id = None
        self._has_mirror = None
        self._has_backup = None
        self._is_remote_clone_source = None
        self._has_snapshots = None
        self._shadow_copy_enabled = None
        self._is_shadow_copy_clone = None
        self._read_iops_limit = None
        self._read_mbps_limit = None
        self._write_iops_limit = None
        self._write_mbps_limit = None
        self._read_iops_capping = None
        self._read_mbps_capping = None
        self._write_iops_capping = None
        self._write_mbps_capping = None
        self._compress = None
        self._dedupe = None
        self._mtr_histograms = None
        self._flc_state = None
        self._flc_scan_state = None
        self._flc_scan_progress = None
        self._flc_scan_remaining_time_seconds = None
        self._thresholds = None
        self._comment = None
        self._created_at = None
        self._modified_at = None
        self._data_type = None
        self._flc_policy_name = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if display_name is not None:
            self.display_name = display_name
        if cg_display_name is not None:
            self.cg_display_name = cg_display_name
        if cg_name is not None:
            self.cg_name = cg_name
        if cg_user_created is not None:
            self.cg_user_created = cg_user_created
        if pool_display_name is not None:
            self.pool_display_name = pool_display_name
        if pool_name is not None:
            self.pool_name = pool_name
        if pool_version is not None:
            self.pool_version = pool_version
        if status is not None:
            self.status = status
        if virtual_capacity is not None:
            self.virtual_capacity = virtual_capacity
        if server_name is not None:
            self.server_name = server_name
        if av_scan_policy_name is not None:
            self.av_scan_policy_name = av_scan_policy_name
        if provisioned_capacity is not None:
            self.provisioned_capacity = provisioned_capacity
        if server_ext_names is not None:
            self.server_ext_names = server_ext_names
        if life_cycle_policy_display_name is not None:
            self.life_cycle_policy_display_name = life_cycle_policy_display_name
        if life_cycle_policy_ext_name is not None:
            self.life_cycle_policy_ext_name = life_cycle_policy_ext_name
        if thin is not None:
            self.thin = thin
        if encryption is not None:
            self.encryption = encryption
        if encryption_key_size is not None:
            self.encryption_key_size = encryption_key_size
        if total_capacity is not None:
            self.total_capacity = total_capacity
        if available_capacity is not None:
            self.available_capacity = available_capacity
        if num_of_filesystem_objects is not None:
            self.num_of_filesystem_objects = num_of_filesystem_objects
        if capacity_mode is not None:
            self.capacity_mode = capacity_mode
        if allocated_capacity is not None:
            self.allocated_capacity = allocated_capacity
        if data_copies_capacity is not None:
            self.data_copies_capacity = data_copies_capacity
        if access_type is not None:
            self.access_type = access_type
        if read_only is not None:
            self.read_only = read_only
        if nfs_export_path is not None:
            self.nfs_export_path = nfs_export_path
        if smb_export_path is not None:
            self.smb_export_path = smb_export_path
        if additional_smb_export_paths_count is not None:
            self.additional_smb_export_paths_count = additional_smb_export_paths_count
        if mount_sync is not None:
            self.mount_sync = mount_sync
        if atime_update is not None:
            self.atime_update = atime_update
        if read_ahead_kb is not None:
            self.read_ahead_kb = read_ahead_kb
        if ext_metering is not None:
            self.ext_metering = ext_metering
        if images_repo is not None:
            self.images_repo = images_repo
        if flc_db is not None:
            self.flc_db = flc_db
        if quarantine_repo is not None:
            self.quarantine_repo = quarantine_repo
        if audit_repo is not None:
            self.audit_repo = audit_repo
        if nfs_root_squash is not None:
            self.nfs_root_squash = nfs_root_squash
        if nfs_all_squash is not None:
            self.nfs_all_squash = nfs_all_squash
        if nfs_anon_uid is not None:
            self.nfs_anon_uid = nfs_anon_uid
        if nfs_anon_gid is not None:
            self.nfs_anon_gid = nfs_anon_gid
        if smb_only is not None:
            self.smb_only = smb_only
        if smb_guest is not None:
            self.smb_guest = smb_guest
        if smb_windows_acl is not None:
            self.smb_windows_acl = smb_windows_acl
        if smb_map_archive is not None:
            self.smb_map_archive = smb_map_archive
        if smb_file_create_mask is not None:
            self.smb_file_create_mask = smb_file_create_mask
        if smb_dir_create_mask is not None:
            self.smb_dir_create_mask = smb_dir_create_mask
        if smb_aio_size is not None:
            self.smb_aio_size = smb_aio_size
        if smb_browseable is not None:
            self.smb_browseable = smb_browseable
        if smb_hidden_files is not None:
            self.smb_hidden_files = smb_hidden_files
        if smb_encryption_mode is not None:
            self.smb_encryption_mode = smb_encryption_mode
        if smb_case_sensitive is not None:
            self.smb_case_sensitive = smb_case_sensitive
        if smb_mangled_names is not None:
            self.smb_mangled_names = smb_mangled_names
        if smb_hide_unreadable is not None:
            self.smb_hide_unreadable = smb_hide_unreadable
        if smb_hide_unwriteable is not None:
            self.smb_hide_unwriteable = smb_hide_unwriteable
        if smb_hide_dot_files is not None:
            self.smb_hide_dot_files = smb_hide_dot_files
        if smb_store_dos_attributes is not None:
            self.smb_store_dos_attributes = smb_store_dos_attributes
        if smb_enable_oplocks is not None:
            self.smb_enable_oplocks = smb_enable_oplocks
        if audit_enable is not None:
            self.audit_enable = audit_enable
        if capacity_history is not None:
            self.capacity_history = capacity_history
        if alert_mode is not None:
            self.alert_mode = alert_mode
        if emergency_mode_mb is not None:
            self.emergency_mode_mb = emergency_mode_mb
        if auto_expand_on_emergency is not None:
            self.auto_expand_on_emergency = auto_expand_on_emergency
        if auto_expand_by is not None:
            self.auto_expand_by = auto_expand_by
        if max_capacity is not None:
            self.max_capacity = max_capacity
        if uquota_state is not None:
            self.uquota_state = uquota_state
        if gquota_state is not None:
            self.gquota_state = gquota_state
        if pquota_state is not None:
            self.pquota_state = pquota_state
        if target is not None:
            self.target = target
        if lun is not None:
            self.lun = lun
        if cache is not None:
            self.cache = cache
        if tenant_id is not None:
            self.tenant_id = tenant_id
        if has_mirror is not None:
            self.has_mirror = has_mirror
        if has_backup is not None:
            self.has_backup = has_backup
        if is_remote_clone_source is not None:
            self.is_remote_clone_source = is_remote_clone_source
        if has_snapshots is not None:
            self.has_snapshots = has_snapshots
        if shadow_copy_enabled is not None:
            self.shadow_copy_enabled = shadow_copy_enabled
        if is_shadow_copy_clone is not None:
            self.is_shadow_copy_clone = is_shadow_copy_clone
        if read_iops_limit is not None:
            self.read_iops_limit = read_iops_limit
        if read_mbps_limit is not None:
            self.read_mbps_limit = read_mbps_limit
        if write_iops_limit is not None:
            self.write_iops_limit = write_iops_limit
        if write_mbps_limit is not None:
            self.write_mbps_limit = write_mbps_limit
        if read_iops_capping is not None:
            self.read_iops_capping = read_iops_capping
        if read_mbps_capping is not None:
            self.read_mbps_capping = read_mbps_capping
        if write_iops_capping is not None:
            self.write_iops_capping = write_iops_capping
        if write_mbps_capping is not None:
            self.write_mbps_capping = write_mbps_capping
        if compress is not None:
            self.compress = compress
        if dedupe is not None:
            self.dedupe = dedupe
        if mtr_histograms is not None:
            self.mtr_histograms = mtr_histograms
        if flc_state is not None:
            self.flc_state = flc_state
        if flc_scan_state is not None:
            self.flc_scan_state = flc_scan_state
        if flc_scan_progress is not None:
            self.flc_scan_progress = flc_scan_progress
        if flc_scan_remaining_time_seconds is not None:
            self.flc_scan_remaining_time_seconds = flc_scan_remaining_time_seconds
        if thresholds is not None:
            self.thresholds = thresholds
        if comment is not None:
            self.comment = comment
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at
        if data_type is not None:
            self.data_type = data_type
        if flc_policy_name is not None:
            self.flc_policy_name = flc_policy_name

    @property
    def name(self):
        """Gets the name of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The name of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse20082ResponseVolumes.


        :param name: The name of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def display_name(self):
        """Gets the display_name of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The display_name of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this InlineResponse20082ResponseVolumes.


        :param display_name: The display_name of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def cg_display_name(self):
        """Gets the cg_display_name of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The cg_display_name of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._cg_display_name

    @cg_display_name.setter
    def cg_display_name(self, cg_display_name):
        """Sets the cg_display_name of this InlineResponse20082ResponseVolumes.


        :param cg_display_name: The cg_display_name of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._cg_display_name = cg_display_name

    @property
    def cg_name(self):
        """Gets the cg_name of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The cg_name of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._cg_name

    @cg_name.setter
    def cg_name(self, cg_name):
        """Sets the cg_name of this InlineResponse20082ResponseVolumes.


        :param cg_name: The cg_name of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._cg_name = cg_name

    @property
    def cg_user_created(self):
        """Gets the cg_user_created of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The cg_user_created of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._cg_user_created

    @cg_user_created.setter
    def cg_user_created(self, cg_user_created):
        """Sets the cg_user_created of this InlineResponse20082ResponseVolumes.


        :param cg_user_created: The cg_user_created of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._cg_user_created = cg_user_created

    @property
    def pool_display_name(self):
        """Gets the pool_display_name of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The pool_display_name of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._pool_display_name

    @pool_display_name.setter
    def pool_display_name(self, pool_display_name):
        """Sets the pool_display_name of this InlineResponse20082ResponseVolumes.


        :param pool_display_name: The pool_display_name of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._pool_display_name = pool_display_name

    @property
    def pool_name(self):
        """Gets the pool_name of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The pool_name of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._pool_name

    @pool_name.setter
    def pool_name(self, pool_name):
        """Sets the pool_name of this InlineResponse20082ResponseVolumes.


        :param pool_name: The pool_name of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._pool_name = pool_name

    @property
    def pool_version(self):
        """Gets the pool_version of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The pool_version of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: int
        """
        return self._pool_version

    @pool_version.setter
    def pool_version(self, pool_version):
        """Sets the pool_version of this InlineResponse20082ResponseVolumes.


        :param pool_version: The pool_version of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: int
        """

        self._pool_version = pool_version

    @property
    def status(self):
        """Gets the status of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The status of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InlineResponse20082ResponseVolumes.


        :param status: The status of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def virtual_capacity(self):
        """Gets the virtual_capacity of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The virtual_capacity of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: int
        """
        return self._virtual_capacity

    @virtual_capacity.setter
    def virtual_capacity(self, virtual_capacity):
        """Sets the virtual_capacity of this InlineResponse20082ResponseVolumes.


        :param virtual_capacity: The virtual_capacity of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: int
        """

        self._virtual_capacity = virtual_capacity

    @property
    def server_name(self):
        """Gets the server_name of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The server_name of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._server_name

    @server_name.setter
    def server_name(self, server_name):
        """Sets the server_name of this InlineResponse20082ResponseVolumes.


        :param server_name: The server_name of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._server_name = server_name

    @property
    def av_scan_policy_name(self):
        """Gets the av_scan_policy_name of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The av_scan_policy_name of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._av_scan_policy_name

    @av_scan_policy_name.setter
    def av_scan_policy_name(self, av_scan_policy_name):
        """Sets the av_scan_policy_name of this InlineResponse20082ResponseVolumes.


        :param av_scan_policy_name: The av_scan_policy_name of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._av_scan_policy_name = av_scan_policy_name

    @property
    def provisioned_capacity(self):
        """Gets the provisioned_capacity of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The provisioned_capacity of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: int
        """
        return self._provisioned_capacity

    @provisioned_capacity.setter
    def provisioned_capacity(self, provisioned_capacity):
        """Sets the provisioned_capacity of this InlineResponse20082ResponseVolumes.


        :param provisioned_capacity: The provisioned_capacity of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: int
        """

        self._provisioned_capacity = provisioned_capacity

    @property
    def server_ext_names(self):
        """Gets the server_ext_names of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The server_ext_names of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._server_ext_names

    @server_ext_names.setter
    def server_ext_names(self, server_ext_names):
        """Sets the server_ext_names of this InlineResponse20082ResponseVolumes.


        :param server_ext_names: The server_ext_names of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._server_ext_names = server_ext_names

    @property
    def life_cycle_policy_display_name(self):
        """Gets the life_cycle_policy_display_name of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The life_cycle_policy_display_name of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._life_cycle_policy_display_name

    @life_cycle_policy_display_name.setter
    def life_cycle_policy_display_name(self, life_cycle_policy_display_name):
        """Sets the life_cycle_policy_display_name of this InlineResponse20082ResponseVolumes.


        :param life_cycle_policy_display_name: The life_cycle_policy_display_name of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._life_cycle_policy_display_name = life_cycle_policy_display_name

    @property
    def life_cycle_policy_ext_name(self):
        """Gets the life_cycle_policy_ext_name of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The life_cycle_policy_ext_name of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._life_cycle_policy_ext_name

    @life_cycle_policy_ext_name.setter
    def life_cycle_policy_ext_name(self, life_cycle_policy_ext_name):
        """Sets the life_cycle_policy_ext_name of this InlineResponse20082ResponseVolumes.


        :param life_cycle_policy_ext_name: The life_cycle_policy_ext_name of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._life_cycle_policy_ext_name = life_cycle_policy_ext_name

    @property
    def thin(self):
        """Gets the thin of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The thin of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._thin

    @thin.setter
    def thin(self, thin):
        """Sets the thin of this InlineResponse20082ResponseVolumes.


        :param thin: The thin of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._thin = thin

    @property
    def encryption(self):
        """Gets the encryption of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The encryption of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._encryption

    @encryption.setter
    def encryption(self, encryption):
        """Sets the encryption of this InlineResponse20082ResponseVolumes.


        :param encryption: The encryption of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._encryption = encryption

    @property
    def encryption_key_size(self):
        """Gets the encryption_key_size of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The encryption_key_size of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._encryption_key_size

    @encryption_key_size.setter
    def encryption_key_size(self, encryption_key_size):
        """Sets the encryption_key_size of this InlineResponse20082ResponseVolumes.


        :param encryption_key_size: The encryption_key_size of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._encryption_key_size = encryption_key_size

    @property
    def total_capacity(self):
        """Gets the total_capacity of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The total_capacity of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: float
        """
        return self._total_capacity

    @total_capacity.setter
    def total_capacity(self, total_capacity):
        """Sets the total_capacity of this InlineResponse20082ResponseVolumes.


        :param total_capacity: The total_capacity of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: float
        """

        self._total_capacity = total_capacity

    @property
    def available_capacity(self):
        """Gets the available_capacity of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The available_capacity of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: float
        """
        return self._available_capacity

    @available_capacity.setter
    def available_capacity(self, available_capacity):
        """Sets the available_capacity of this InlineResponse20082ResponseVolumes.


        :param available_capacity: The available_capacity of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: float
        """

        self._available_capacity = available_capacity

    @property
    def num_of_filesystem_objects(self):
        """Gets the num_of_filesystem_objects of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The num_of_filesystem_objects of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: int
        """
        return self._num_of_filesystem_objects

    @num_of_filesystem_objects.setter
    def num_of_filesystem_objects(self, num_of_filesystem_objects):
        """Sets the num_of_filesystem_objects of this InlineResponse20082ResponseVolumes.


        :param num_of_filesystem_objects: The num_of_filesystem_objects of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: int
        """

        self._num_of_filesystem_objects = num_of_filesystem_objects

    @property
    def capacity_mode(self):
        """Gets the capacity_mode of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The capacity_mode of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._capacity_mode

    @capacity_mode.setter
    def capacity_mode(self, capacity_mode):
        """Sets the capacity_mode of this InlineResponse20082ResponseVolumes.


        :param capacity_mode: The capacity_mode of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._capacity_mode = capacity_mode

    @property
    def allocated_capacity(self):
        """Gets the allocated_capacity of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The allocated_capacity of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: float
        """
        return self._allocated_capacity

    @allocated_capacity.setter
    def allocated_capacity(self, allocated_capacity):
        """Sets the allocated_capacity of this InlineResponse20082ResponseVolumes.


        :param allocated_capacity: The allocated_capacity of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: float
        """

        self._allocated_capacity = allocated_capacity

    @property
    def data_copies_capacity(self):
        """Gets the data_copies_capacity of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The data_copies_capacity of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: float
        """
        return self._data_copies_capacity

    @data_copies_capacity.setter
    def data_copies_capacity(self, data_copies_capacity):
        """Sets the data_copies_capacity of this InlineResponse20082ResponseVolumes.


        :param data_copies_capacity: The data_copies_capacity of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: float
        """

        self._data_copies_capacity = data_copies_capacity

    @property
    def access_type(self):
        """Gets the access_type of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The access_type of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._access_type

    @access_type.setter
    def access_type(self, access_type):
        """Sets the access_type of this InlineResponse20082ResponseVolumes.


        :param access_type: The access_type of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._access_type = access_type

    @property
    def read_only(self):
        """Gets the read_only of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The read_only of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._read_only

    @read_only.setter
    def read_only(self, read_only):
        """Sets the read_only of this InlineResponse20082ResponseVolumes.


        :param read_only: The read_only of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._read_only = read_only

    @property
    def nfs_export_path(self):
        """Gets the nfs_export_path of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The nfs_export_path of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._nfs_export_path

    @nfs_export_path.setter
    def nfs_export_path(self, nfs_export_path):
        """Sets the nfs_export_path of this InlineResponse20082ResponseVolumes.


        :param nfs_export_path: The nfs_export_path of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._nfs_export_path = nfs_export_path

    @property
    def smb_export_path(self):
        """Gets the smb_export_path of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The smb_export_path of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._smb_export_path

    @smb_export_path.setter
    def smb_export_path(self, smb_export_path):
        """Sets the smb_export_path of this InlineResponse20082ResponseVolumes.


        :param smb_export_path: The smb_export_path of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._smb_export_path = smb_export_path

    @property
    def additional_smb_export_paths_count(self):
        """Gets the additional_smb_export_paths_count of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The additional_smb_export_paths_count of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: int
        """
        return self._additional_smb_export_paths_count

    @additional_smb_export_paths_count.setter
    def additional_smb_export_paths_count(self, additional_smb_export_paths_count):
        """Sets the additional_smb_export_paths_count of this InlineResponse20082ResponseVolumes.


        :param additional_smb_export_paths_count: The additional_smb_export_paths_count of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: int
        """

        self._additional_smb_export_paths_count = additional_smb_export_paths_count

    @property
    def mount_sync(self):
        """Gets the mount_sync of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The mount_sync of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._mount_sync

    @mount_sync.setter
    def mount_sync(self, mount_sync):
        """Sets the mount_sync of this InlineResponse20082ResponseVolumes.


        :param mount_sync: The mount_sync of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._mount_sync = mount_sync

    @property
    def atime_update(self):
        """Gets the atime_update of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The atime_update of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._atime_update

    @atime_update.setter
    def atime_update(self, atime_update):
        """Sets the atime_update of this InlineResponse20082ResponseVolumes.


        :param atime_update: The atime_update of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._atime_update = atime_update

    @property
    def read_ahead_kb(self):
        """Gets the read_ahead_kb of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The read_ahead_kb of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: int
        """
        return self._read_ahead_kb

    @read_ahead_kb.setter
    def read_ahead_kb(self, read_ahead_kb):
        """Sets the read_ahead_kb of this InlineResponse20082ResponseVolumes.


        :param read_ahead_kb: The read_ahead_kb of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: int
        """

        self._read_ahead_kb = read_ahead_kb

    @property
    def ext_metering(self):
        """Gets the ext_metering of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The ext_metering of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._ext_metering

    @ext_metering.setter
    def ext_metering(self, ext_metering):
        """Sets the ext_metering of this InlineResponse20082ResponseVolumes.


        :param ext_metering: The ext_metering of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._ext_metering = ext_metering

    @property
    def images_repo(self):
        """Gets the images_repo of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The images_repo of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._images_repo

    @images_repo.setter
    def images_repo(self, images_repo):
        """Sets the images_repo of this InlineResponse20082ResponseVolumes.


        :param images_repo: The images_repo of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._images_repo = images_repo

    @property
    def flc_db(self):
        """Gets the flc_db of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The flc_db of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._flc_db

    @flc_db.setter
    def flc_db(self, flc_db):
        """Sets the flc_db of this InlineResponse20082ResponseVolumes.


        :param flc_db: The flc_db of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._flc_db = flc_db

    @property
    def quarantine_repo(self):
        """Gets the quarantine_repo of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The quarantine_repo of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._quarantine_repo

    @quarantine_repo.setter
    def quarantine_repo(self, quarantine_repo):
        """Sets the quarantine_repo of this InlineResponse20082ResponseVolumes.


        :param quarantine_repo: The quarantine_repo of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._quarantine_repo = quarantine_repo

    @property
    def audit_repo(self):
        """Gets the audit_repo of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The audit_repo of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._audit_repo

    @audit_repo.setter
    def audit_repo(self, audit_repo):
        """Sets the audit_repo of this InlineResponse20082ResponseVolumes.


        :param audit_repo: The audit_repo of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._audit_repo = audit_repo

    @property
    def nfs_root_squash(self):
        """Gets the nfs_root_squash of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The nfs_root_squash of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._nfs_root_squash

    @nfs_root_squash.setter
    def nfs_root_squash(self, nfs_root_squash):
        """Sets the nfs_root_squash of this InlineResponse20082ResponseVolumes.


        :param nfs_root_squash: The nfs_root_squash of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._nfs_root_squash = nfs_root_squash

    @property
    def nfs_all_squash(self):
        """Gets the nfs_all_squash of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The nfs_all_squash of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._nfs_all_squash

    @nfs_all_squash.setter
    def nfs_all_squash(self, nfs_all_squash):
        """Sets the nfs_all_squash of this InlineResponse20082ResponseVolumes.


        :param nfs_all_squash: The nfs_all_squash of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._nfs_all_squash = nfs_all_squash

    @property
    def nfs_anon_uid(self):
        """Gets the nfs_anon_uid of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The nfs_anon_uid of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._nfs_anon_uid

    @nfs_anon_uid.setter
    def nfs_anon_uid(self, nfs_anon_uid):
        """Sets the nfs_anon_uid of this InlineResponse20082ResponseVolumes.


        :param nfs_anon_uid: The nfs_anon_uid of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._nfs_anon_uid = nfs_anon_uid

    @property
    def nfs_anon_gid(self):
        """Gets the nfs_anon_gid of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The nfs_anon_gid of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._nfs_anon_gid

    @nfs_anon_gid.setter
    def nfs_anon_gid(self, nfs_anon_gid):
        """Sets the nfs_anon_gid of this InlineResponse20082ResponseVolumes.


        :param nfs_anon_gid: The nfs_anon_gid of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._nfs_anon_gid = nfs_anon_gid

    @property
    def smb_only(self):
        """Gets the smb_only of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The smb_only of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._smb_only

    @smb_only.setter
    def smb_only(self, smb_only):
        """Sets the smb_only of this InlineResponse20082ResponseVolumes.


        :param smb_only: The smb_only of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._smb_only = smb_only

    @property
    def smb_guest(self):
        """Gets the smb_guest of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The smb_guest of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._smb_guest

    @smb_guest.setter
    def smb_guest(self, smb_guest):
        """Sets the smb_guest of this InlineResponse20082ResponseVolumes.


        :param smb_guest: The smb_guest of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._smb_guest = smb_guest

    @property
    def smb_windows_acl(self):
        """Gets the smb_windows_acl of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The smb_windows_acl of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._smb_windows_acl

    @smb_windows_acl.setter
    def smb_windows_acl(self, smb_windows_acl):
        """Sets the smb_windows_acl of this InlineResponse20082ResponseVolumes.


        :param smb_windows_acl: The smb_windows_acl of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._smb_windows_acl = smb_windows_acl

    @property
    def smb_map_archive(self):
        """Gets the smb_map_archive of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The smb_map_archive of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._smb_map_archive

    @smb_map_archive.setter
    def smb_map_archive(self, smb_map_archive):
        """Sets the smb_map_archive of this InlineResponse20082ResponseVolumes.


        :param smb_map_archive: The smb_map_archive of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._smb_map_archive = smb_map_archive

    @property
    def smb_file_create_mask(self):
        """Gets the smb_file_create_mask of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The smb_file_create_mask of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._smb_file_create_mask

    @smb_file_create_mask.setter
    def smb_file_create_mask(self, smb_file_create_mask):
        """Sets the smb_file_create_mask of this InlineResponse20082ResponseVolumes.


        :param smb_file_create_mask: The smb_file_create_mask of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._smb_file_create_mask = smb_file_create_mask

    @property
    def smb_dir_create_mask(self):
        """Gets the smb_dir_create_mask of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The smb_dir_create_mask of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._smb_dir_create_mask

    @smb_dir_create_mask.setter
    def smb_dir_create_mask(self, smb_dir_create_mask):
        """Sets the smb_dir_create_mask of this InlineResponse20082ResponseVolumes.


        :param smb_dir_create_mask: The smb_dir_create_mask of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._smb_dir_create_mask = smb_dir_create_mask

    @property
    def smb_aio_size(self):
        """Gets the smb_aio_size of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The smb_aio_size of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: int
        """
        return self._smb_aio_size

    @smb_aio_size.setter
    def smb_aio_size(self, smb_aio_size):
        """Sets the smb_aio_size of this InlineResponse20082ResponseVolumes.


        :param smb_aio_size: The smb_aio_size of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: int
        """

        self._smb_aio_size = smb_aio_size

    @property
    def smb_browseable(self):
        """Gets the smb_browseable of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The smb_browseable of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._smb_browseable

    @smb_browseable.setter
    def smb_browseable(self, smb_browseable):
        """Sets the smb_browseable of this InlineResponse20082ResponseVolumes.


        :param smb_browseable: The smb_browseable of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._smb_browseable = smb_browseable

    @property
    def smb_hidden_files(self):
        """Gets the smb_hidden_files of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The smb_hidden_files of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._smb_hidden_files

    @smb_hidden_files.setter
    def smb_hidden_files(self, smb_hidden_files):
        """Sets the smb_hidden_files of this InlineResponse20082ResponseVolumes.


        :param smb_hidden_files: The smb_hidden_files of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._smb_hidden_files = smb_hidden_files

    @property
    def smb_encryption_mode(self):
        """Gets the smb_encryption_mode of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The smb_encryption_mode of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._smb_encryption_mode

    @smb_encryption_mode.setter
    def smb_encryption_mode(self, smb_encryption_mode):
        """Sets the smb_encryption_mode of this InlineResponse20082ResponseVolumes.


        :param smb_encryption_mode: The smb_encryption_mode of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._smb_encryption_mode = smb_encryption_mode

    @property
    def smb_case_sensitive(self):
        """Gets the smb_case_sensitive of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The smb_case_sensitive of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._smb_case_sensitive

    @smb_case_sensitive.setter
    def smb_case_sensitive(self, smb_case_sensitive):
        """Sets the smb_case_sensitive of this InlineResponse20082ResponseVolumes.


        :param smb_case_sensitive: The smb_case_sensitive of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._smb_case_sensitive = smb_case_sensitive

    @property
    def smb_mangled_names(self):
        """Gets the smb_mangled_names of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The smb_mangled_names of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._smb_mangled_names

    @smb_mangled_names.setter
    def smb_mangled_names(self, smb_mangled_names):
        """Sets the smb_mangled_names of this InlineResponse20082ResponseVolumes.


        :param smb_mangled_names: The smb_mangled_names of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._smb_mangled_names = smb_mangled_names

    @property
    def smb_hide_unreadable(self):
        """Gets the smb_hide_unreadable of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The smb_hide_unreadable of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._smb_hide_unreadable

    @smb_hide_unreadable.setter
    def smb_hide_unreadable(self, smb_hide_unreadable):
        """Sets the smb_hide_unreadable of this InlineResponse20082ResponseVolumes.


        :param smb_hide_unreadable: The smb_hide_unreadable of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._smb_hide_unreadable = smb_hide_unreadable

    @property
    def smb_hide_unwriteable(self):
        """Gets the smb_hide_unwriteable of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The smb_hide_unwriteable of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._smb_hide_unwriteable

    @smb_hide_unwriteable.setter
    def smb_hide_unwriteable(self, smb_hide_unwriteable):
        """Sets the smb_hide_unwriteable of this InlineResponse20082ResponseVolumes.


        :param smb_hide_unwriteable: The smb_hide_unwriteable of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._smb_hide_unwriteable = smb_hide_unwriteable

    @property
    def smb_hide_dot_files(self):
        """Gets the smb_hide_dot_files of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The smb_hide_dot_files of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._smb_hide_dot_files

    @smb_hide_dot_files.setter
    def smb_hide_dot_files(self, smb_hide_dot_files):
        """Sets the smb_hide_dot_files of this InlineResponse20082ResponseVolumes.


        :param smb_hide_dot_files: The smb_hide_dot_files of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._smb_hide_dot_files = smb_hide_dot_files

    @property
    def smb_store_dos_attributes(self):
        """Gets the smb_store_dos_attributes of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The smb_store_dos_attributes of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._smb_store_dos_attributes

    @smb_store_dos_attributes.setter
    def smb_store_dos_attributes(self, smb_store_dos_attributes):
        """Sets the smb_store_dos_attributes of this InlineResponse20082ResponseVolumes.


        :param smb_store_dos_attributes: The smb_store_dos_attributes of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._smb_store_dos_attributes = smb_store_dos_attributes

    @property
    def smb_enable_oplocks(self):
        """Gets the smb_enable_oplocks of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The smb_enable_oplocks of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._smb_enable_oplocks

    @smb_enable_oplocks.setter
    def smb_enable_oplocks(self, smb_enable_oplocks):
        """Sets the smb_enable_oplocks of this InlineResponse20082ResponseVolumes.


        :param smb_enable_oplocks: The smb_enable_oplocks of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._smb_enable_oplocks = smb_enable_oplocks

    @property
    def audit_enable(self):
        """Gets the audit_enable of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The audit_enable of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._audit_enable

    @audit_enable.setter
    def audit_enable(self, audit_enable):
        """Sets the audit_enable of this InlineResponse20082ResponseVolumes.


        :param audit_enable: The audit_enable of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._audit_enable = audit_enable

    @property
    def capacity_history(self):
        """Gets the capacity_history of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The capacity_history of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: int
        """
        return self._capacity_history

    @capacity_history.setter
    def capacity_history(self, capacity_history):
        """Sets the capacity_history of this InlineResponse20082ResponseVolumes.


        :param capacity_history: The capacity_history of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: int
        """

        self._capacity_history = capacity_history

    @property
    def alert_mode(self):
        """Gets the alert_mode of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The alert_mode of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: int
        """
        return self._alert_mode

    @alert_mode.setter
    def alert_mode(self, alert_mode):
        """Sets the alert_mode of this InlineResponse20082ResponseVolumes.


        :param alert_mode: The alert_mode of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: int
        """

        self._alert_mode = alert_mode

    @property
    def emergency_mode_mb(self):
        """Gets the emergency_mode_mb of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The emergency_mode_mb of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: int
        """
        return self._emergency_mode_mb

    @emergency_mode_mb.setter
    def emergency_mode_mb(self, emergency_mode_mb):
        """Sets the emergency_mode_mb of this InlineResponse20082ResponseVolumes.


        :param emergency_mode_mb: The emergency_mode_mb of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: int
        """

        self._emergency_mode_mb = emergency_mode_mb

    @property
    def auto_expand_on_emergency(self):
        """Gets the auto_expand_on_emergency of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The auto_expand_on_emergency of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._auto_expand_on_emergency

    @auto_expand_on_emergency.setter
    def auto_expand_on_emergency(self, auto_expand_on_emergency):
        """Sets the auto_expand_on_emergency of this InlineResponse20082ResponseVolumes.


        :param auto_expand_on_emergency: The auto_expand_on_emergency of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._auto_expand_on_emergency = auto_expand_on_emergency

    @property
    def auto_expand_by(self):
        """Gets the auto_expand_by of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The auto_expand_by of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: int
        """
        return self._auto_expand_by

    @auto_expand_by.setter
    def auto_expand_by(self, auto_expand_by):
        """Sets the auto_expand_by of this InlineResponse20082ResponseVolumes.


        :param auto_expand_by: The auto_expand_by of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: int
        """

        self._auto_expand_by = auto_expand_by

    @property
    def max_capacity(self):
        """Gets the max_capacity of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The max_capacity of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: int
        """
        return self._max_capacity

    @max_capacity.setter
    def max_capacity(self, max_capacity):
        """Sets the max_capacity of this InlineResponse20082ResponseVolumes.


        :param max_capacity: The max_capacity of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: int
        """

        self._max_capacity = max_capacity

    @property
    def uquota_state(self):
        """Gets the uquota_state of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The uquota_state of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._uquota_state

    @uquota_state.setter
    def uquota_state(self, uquota_state):
        """Sets the uquota_state of this InlineResponse20082ResponseVolumes.


        :param uquota_state: The uquota_state of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._uquota_state = uquota_state

    @property
    def gquota_state(self):
        """Gets the gquota_state of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The gquota_state of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._gquota_state

    @gquota_state.setter
    def gquota_state(self, gquota_state):
        """Sets the gquota_state of this InlineResponse20082ResponseVolumes.


        :param gquota_state: The gquota_state of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._gquota_state = gquota_state

    @property
    def pquota_state(self):
        """Gets the pquota_state of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The pquota_state of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._pquota_state

    @pquota_state.setter
    def pquota_state(self, pquota_state):
        """Sets the pquota_state of this InlineResponse20082ResponseVolumes.


        :param pquota_state: The pquota_state of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._pquota_state = pquota_state

    @property
    def target(self):
        """Gets the target of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The target of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._target

    @target.setter
    def target(self, target):
        """Sets the target of this InlineResponse20082ResponseVolumes.


        :param target: The target of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._target = target

    @property
    def lun(self):
        """Gets the lun of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The lun of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._lun

    @lun.setter
    def lun(self, lun):
        """Sets the lun of this InlineResponse20082ResponseVolumes.


        :param lun: The lun of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._lun = lun

    @property
    def cache(self):
        """Gets the cache of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The cache of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._cache

    @cache.setter
    def cache(self, cache):
        """Sets the cache of this InlineResponse20082ResponseVolumes.


        :param cache: The cache of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._cache = cache

    @property
    def tenant_id(self):
        """Gets the tenant_id of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The tenant_id of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: int
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this InlineResponse20082ResponseVolumes.


        :param tenant_id: The tenant_id of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: int
        """

        self._tenant_id = tenant_id

    @property
    def has_mirror(self):
        """Gets the has_mirror of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The has_mirror of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._has_mirror

    @has_mirror.setter
    def has_mirror(self, has_mirror):
        """Sets the has_mirror of this InlineResponse20082ResponseVolumes.


        :param has_mirror: The has_mirror of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._has_mirror = has_mirror

    @property
    def has_backup(self):
        """Gets the has_backup of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The has_backup of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._has_backup

    @has_backup.setter
    def has_backup(self, has_backup):
        """Sets the has_backup of this InlineResponse20082ResponseVolumes.


        :param has_backup: The has_backup of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._has_backup = has_backup

    @property
    def is_remote_clone_source(self):
        """Gets the is_remote_clone_source of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The is_remote_clone_source of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._is_remote_clone_source

    @is_remote_clone_source.setter
    def is_remote_clone_source(self, is_remote_clone_source):
        """Sets the is_remote_clone_source of this InlineResponse20082ResponseVolumes.


        :param is_remote_clone_source: The is_remote_clone_source of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._is_remote_clone_source = is_remote_clone_source

    @property
    def has_snapshots(self):
        """Gets the has_snapshots of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The has_snapshots of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._has_snapshots

    @has_snapshots.setter
    def has_snapshots(self, has_snapshots):
        """Sets the has_snapshots of this InlineResponse20082ResponseVolumes.


        :param has_snapshots: The has_snapshots of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._has_snapshots = has_snapshots

    @property
    def shadow_copy_enabled(self):
        """Gets the shadow_copy_enabled of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The shadow_copy_enabled of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._shadow_copy_enabled

    @shadow_copy_enabled.setter
    def shadow_copy_enabled(self, shadow_copy_enabled):
        """Sets the shadow_copy_enabled of this InlineResponse20082ResponseVolumes.


        :param shadow_copy_enabled: The shadow_copy_enabled of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._shadow_copy_enabled = shadow_copy_enabled

    @property
    def is_shadow_copy_clone(self):
        """Gets the is_shadow_copy_clone of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The is_shadow_copy_clone of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._is_shadow_copy_clone

    @is_shadow_copy_clone.setter
    def is_shadow_copy_clone(self, is_shadow_copy_clone):
        """Sets the is_shadow_copy_clone of this InlineResponse20082ResponseVolumes.


        :param is_shadow_copy_clone: The is_shadow_copy_clone of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._is_shadow_copy_clone = is_shadow_copy_clone

    @property
    def read_iops_limit(self):
        """Gets the read_iops_limit of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The read_iops_limit of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._read_iops_limit

    @read_iops_limit.setter
    def read_iops_limit(self, read_iops_limit):
        """Sets the read_iops_limit of this InlineResponse20082ResponseVolumes.


        :param read_iops_limit: The read_iops_limit of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._read_iops_limit = read_iops_limit

    @property
    def read_mbps_limit(self):
        """Gets the read_mbps_limit of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The read_mbps_limit of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._read_mbps_limit

    @read_mbps_limit.setter
    def read_mbps_limit(self, read_mbps_limit):
        """Sets the read_mbps_limit of this InlineResponse20082ResponseVolumes.


        :param read_mbps_limit: The read_mbps_limit of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._read_mbps_limit = read_mbps_limit

    @property
    def write_iops_limit(self):
        """Gets the write_iops_limit of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The write_iops_limit of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._write_iops_limit

    @write_iops_limit.setter
    def write_iops_limit(self, write_iops_limit):
        """Sets the write_iops_limit of this InlineResponse20082ResponseVolumes.


        :param write_iops_limit: The write_iops_limit of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._write_iops_limit = write_iops_limit

    @property
    def write_mbps_limit(self):
        """Gets the write_mbps_limit of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The write_mbps_limit of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._write_mbps_limit

    @write_mbps_limit.setter
    def write_mbps_limit(self, write_mbps_limit):
        """Sets the write_mbps_limit of this InlineResponse20082ResponseVolumes.


        :param write_mbps_limit: The write_mbps_limit of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._write_mbps_limit = write_mbps_limit

    @property
    def read_iops_capping(self):
        """Gets the read_iops_capping of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The read_iops_capping of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._read_iops_capping

    @read_iops_capping.setter
    def read_iops_capping(self, read_iops_capping):
        """Sets the read_iops_capping of this InlineResponse20082ResponseVolumes.


        :param read_iops_capping: The read_iops_capping of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._read_iops_capping = read_iops_capping

    @property
    def read_mbps_capping(self):
        """Gets the read_mbps_capping of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The read_mbps_capping of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._read_mbps_capping

    @read_mbps_capping.setter
    def read_mbps_capping(self, read_mbps_capping):
        """Sets the read_mbps_capping of this InlineResponse20082ResponseVolumes.


        :param read_mbps_capping: The read_mbps_capping of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._read_mbps_capping = read_mbps_capping

    @property
    def write_iops_capping(self):
        """Gets the write_iops_capping of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The write_iops_capping of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._write_iops_capping

    @write_iops_capping.setter
    def write_iops_capping(self, write_iops_capping):
        """Sets the write_iops_capping of this InlineResponse20082ResponseVolumes.


        :param write_iops_capping: The write_iops_capping of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._write_iops_capping = write_iops_capping

    @property
    def write_mbps_capping(self):
        """Gets the write_mbps_capping of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The write_mbps_capping of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._write_mbps_capping

    @write_mbps_capping.setter
    def write_mbps_capping(self, write_mbps_capping):
        """Sets the write_mbps_capping of this InlineResponse20082ResponseVolumes.


        :param write_mbps_capping: The write_mbps_capping of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._write_mbps_capping = write_mbps_capping

    @property
    def compress(self):
        """Gets the compress of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The compress of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._compress

    @compress.setter
    def compress(self, compress):
        """Sets the compress of this InlineResponse20082ResponseVolumes.


        :param compress: The compress of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._compress = compress

    @property
    def dedupe(self):
        """Gets the dedupe of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The dedupe of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._dedupe

    @dedupe.setter
    def dedupe(self, dedupe):
        """Sets the dedupe of this InlineResponse20082ResponseVolumes.


        :param dedupe: The dedupe of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._dedupe = dedupe

    @property
    def mtr_histograms(self):
        """Gets the mtr_histograms of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The mtr_histograms of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._mtr_histograms

    @mtr_histograms.setter
    def mtr_histograms(self, mtr_histograms):
        """Sets the mtr_histograms of this InlineResponse20082ResponseVolumes.


        :param mtr_histograms: The mtr_histograms of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._mtr_histograms = mtr_histograms

    @property
    def flc_state(self):
        """Gets the flc_state of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The flc_state of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._flc_state

    @flc_state.setter
    def flc_state(self, flc_state):
        """Sets the flc_state of this InlineResponse20082ResponseVolumes.


        :param flc_state: The flc_state of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._flc_state = flc_state

    @property
    def flc_scan_state(self):
        """Gets the flc_scan_state of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The flc_scan_state of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._flc_scan_state

    @flc_scan_state.setter
    def flc_scan_state(self, flc_scan_state):
        """Sets the flc_scan_state of this InlineResponse20082ResponseVolumes.


        :param flc_scan_state: The flc_scan_state of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._flc_scan_state = flc_scan_state

    @property
    def flc_scan_progress(self):
        """Gets the flc_scan_progress of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The flc_scan_progress of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: float
        """
        return self._flc_scan_progress

    @flc_scan_progress.setter
    def flc_scan_progress(self, flc_scan_progress):
        """Sets the flc_scan_progress of this InlineResponse20082ResponseVolumes.


        :param flc_scan_progress: The flc_scan_progress of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: float
        """

        self._flc_scan_progress = flc_scan_progress

    @property
    def flc_scan_remaining_time_seconds(self):
        """Gets the flc_scan_remaining_time_seconds of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The flc_scan_remaining_time_seconds of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: int
        """
        return self._flc_scan_remaining_time_seconds

    @flc_scan_remaining_time_seconds.setter
    def flc_scan_remaining_time_seconds(self, flc_scan_remaining_time_seconds):
        """Sets the flc_scan_remaining_time_seconds of this InlineResponse20082ResponseVolumes.


        :param flc_scan_remaining_time_seconds: The flc_scan_remaining_time_seconds of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: int
        """

        self._flc_scan_remaining_time_seconds = flc_scan_remaining_time_seconds

    @property
    def thresholds(self):
        """Gets the thresholds of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The thresholds of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._thresholds

    @thresholds.setter
    def thresholds(self, thresholds):
        """Sets the thresholds of this InlineResponse20082ResponseVolumes.


        :param thresholds: The thresholds of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._thresholds = thresholds

    @property
    def comment(self):
        """Gets the comment of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The comment of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this InlineResponse20082ResponseVolumes.


        :param comment: The comment of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def created_at(self):
        """Gets the created_at of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The created_at of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InlineResponse20082ResponseVolumes.


        :param created_at: The created_at of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The modified_at of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this InlineResponse20082ResponseVolumes.


        :param modified_at: The modified_at of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._modified_at = modified_at

    @property
    def data_type(self):
        """Gets the data_type of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The data_type of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """Sets the data_type of this InlineResponse20082ResponseVolumes.


        :param data_type: The data_type of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._data_type = data_type

    @property
    def flc_policy_name(self):
        """Gets the flc_policy_name of this InlineResponse20082ResponseVolumes.  # noqa: E501


        :return: The flc_policy_name of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._flc_policy_name

    @flc_policy_name.setter
    def flc_policy_name(self, flc_policy_name):
        """Sets the flc_policy_name of this InlineResponse20082ResponseVolumes.


        :param flc_policy_name: The flc_policy_name of this InlineResponse20082ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._flc_policy_name = flc_policy_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20082ResponseVolumes, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20082ResponseVolumes):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20082ResponseVolumes):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class InlineResponse20033ResponseLcPolicies(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'display_name': 'str',
        'enabled': 'str',
        'dry_run_mode': 'str',
        'use_recycle_bin': 'str',
        'file_selection_criteria': 'str',
        'whitelist_paths': 'str',
        'blacklist_paths': 'str',
        'action': 'str',
        'created_at': 'str',
        'modified_at': 'str'
    }

    attribute_map = {
        'name': 'name',
        'display_name': 'display_name',
        'enabled': 'enabled',
        'dry_run_mode': 'dry_run_mode',
        'use_recycle_bin': 'use_recycle_bin',
        'file_selection_criteria': 'file_selection_criteria',
        'whitelist_paths': 'whitelist_paths',
        'blacklist_paths': 'blacklist_paths',
        'action': 'action',
        'created_at': 'created_at',
        'modified_at': 'modified_at'
    }

    def __init__(self, name=None, display_name=None, enabled=None, dry_run_mode=None, use_recycle_bin=None, file_selection_criteria=None, whitelist_paths=None, blacklist_paths=None, action=None, created_at=None, modified_at=None, _configuration=None):  # noqa: E501
        """InlineResponse20033ResponseLcPolicies - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._display_name = None
        self._enabled = None
        self._dry_run_mode = None
        self._use_recycle_bin = None
        self._file_selection_criteria = None
        self._whitelist_paths = None
        self._blacklist_paths = None
        self._action = None
        self._created_at = None
        self._modified_at = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if display_name is not None:
            self.display_name = display_name
        if enabled is not None:
            self.enabled = enabled
        if dry_run_mode is not None:
            self.dry_run_mode = dry_run_mode
        if use_recycle_bin is not None:
            self.use_recycle_bin = use_recycle_bin
        if file_selection_criteria is not None:
            self.file_selection_criteria = file_selection_criteria
        if whitelist_paths is not None:
            self.whitelist_paths = whitelist_paths
        if blacklist_paths is not None:
            self.blacklist_paths = blacklist_paths
        if action is not None:
            self.action = action
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at

    @property
    def name(self):
        """Gets the name of this InlineResponse20033ResponseLcPolicies.  # noqa: E501


        :return: The name of this InlineResponse20033ResponseLcPolicies.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse20033ResponseLcPolicies.


        :param name: The name of this InlineResponse20033ResponseLcPolicies.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def display_name(self):
        """Gets the display_name of this InlineResponse20033ResponseLcPolicies.  # noqa: E501


        :return: The display_name of this InlineResponse20033ResponseLcPolicies.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this InlineResponse20033ResponseLcPolicies.


        :param display_name: The display_name of this InlineResponse20033ResponseLcPolicies.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def enabled(self):
        """Gets the enabled of this InlineResponse20033ResponseLcPolicies.  # noqa: E501


        :return: The enabled of this InlineResponse20033ResponseLcPolicies.  # noqa: E501
        :rtype: str
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this InlineResponse20033ResponseLcPolicies.


        :param enabled: The enabled of this InlineResponse20033ResponseLcPolicies.  # noqa: E501
        :type: str
        """

        self._enabled = enabled

    @property
    def dry_run_mode(self):
        """Gets the dry_run_mode of this InlineResponse20033ResponseLcPolicies.  # noqa: E501


        :return: The dry_run_mode of this InlineResponse20033ResponseLcPolicies.  # noqa: E501
        :rtype: str
        """
        return self._dry_run_mode

    @dry_run_mode.setter
    def dry_run_mode(self, dry_run_mode):
        """Sets the dry_run_mode of this InlineResponse20033ResponseLcPolicies.


        :param dry_run_mode: The dry_run_mode of this InlineResponse20033ResponseLcPolicies.  # noqa: E501
        :type: str
        """

        self._dry_run_mode = dry_run_mode

    @property
    def use_recycle_bin(self):
        """Gets the use_recycle_bin of this InlineResponse20033ResponseLcPolicies.  # noqa: E501


        :return: The use_recycle_bin of this InlineResponse20033ResponseLcPolicies.  # noqa: E501
        :rtype: str
        """
        return self._use_recycle_bin

    @use_recycle_bin.setter
    def use_recycle_bin(self, use_recycle_bin):
        """Sets the use_recycle_bin of this InlineResponse20033ResponseLcPolicies.


        :param use_recycle_bin: The use_recycle_bin of this InlineResponse20033ResponseLcPolicies.  # noqa: E501
        :type: str
        """

        self._use_recycle_bin = use_recycle_bin

    @property
    def file_selection_criteria(self):
        """Gets the file_selection_criteria of this InlineResponse20033ResponseLcPolicies.  # noqa: E501


        :return: The file_selection_criteria of this InlineResponse20033ResponseLcPolicies.  # noqa: E501
        :rtype: str
        """
        return self._file_selection_criteria

    @file_selection_criteria.setter
    def file_selection_criteria(self, file_selection_criteria):
        """Sets the file_selection_criteria of this InlineResponse20033ResponseLcPolicies.


        :param file_selection_criteria: The file_selection_criteria of this InlineResponse20033ResponseLcPolicies.  # noqa: E501
        :type: str
        """

        self._file_selection_criteria = file_selection_criteria

    @property
    def whitelist_paths(self):
        """Gets the whitelist_paths of this InlineResponse20033ResponseLcPolicies.  # noqa: E501


        :return: The whitelist_paths of this InlineResponse20033ResponseLcPolicies.  # noqa: E501
        :rtype: str
        """
        return self._whitelist_paths

    @whitelist_paths.setter
    def whitelist_paths(self, whitelist_paths):
        """Sets the whitelist_paths of this InlineResponse20033ResponseLcPolicies.


        :param whitelist_paths: The whitelist_paths of this InlineResponse20033ResponseLcPolicies.  # noqa: E501
        :type: str
        """

        self._whitelist_paths = whitelist_paths

    @property
    def blacklist_paths(self):
        """Gets the blacklist_paths of this InlineResponse20033ResponseLcPolicies.  # noqa: E501


        :return: The blacklist_paths of this InlineResponse20033ResponseLcPolicies.  # noqa: E501
        :rtype: str
        """
        return self._blacklist_paths

    @blacklist_paths.setter
    def blacklist_paths(self, blacklist_paths):
        """Sets the blacklist_paths of this InlineResponse20033ResponseLcPolicies.


        :param blacklist_paths: The blacklist_paths of this InlineResponse20033ResponseLcPolicies.  # noqa: E501
        :type: str
        """

        self._blacklist_paths = blacklist_paths

    @property
    def action(self):
        """Gets the action of this InlineResponse20033ResponseLcPolicies.  # noqa: E501


        :return: The action of this InlineResponse20033ResponseLcPolicies.  # noqa: E501
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this InlineResponse20033ResponseLcPolicies.


        :param action: The action of this InlineResponse20033ResponseLcPolicies.  # noqa: E501
        :type: str
        """

        self._action = action

    @property
    def created_at(self):
        """Gets the created_at of this InlineResponse20033ResponseLcPolicies.  # noqa: E501


        :return: The created_at of this InlineResponse20033ResponseLcPolicies.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InlineResponse20033ResponseLcPolicies.


        :param created_at: The created_at of this InlineResponse20033ResponseLcPolicies.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this InlineResponse20033ResponseLcPolicies.  # noqa: E501


        :return: The modified_at of this InlineResponse20033ResponseLcPolicies.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this InlineResponse20033ResponseLcPolicies.


        :param modified_at: The modified_at of this InlineResponse20033ResponseLcPolicies.  # noqa: E501
        :type: str
        """

        self._modified_at = modified_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20033ResponseLcPolicies, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20033ResponseLcPolicies):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20033ResponseLcPolicies):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class CreateStoragePolicyZios(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'drive_type': 'str',
        'drive_quantity': 'int',
        'policy_type_id': 'int',
        'description': 'str'
    }

    attribute_map = {
        'name': 'name',
        'drive_type': 'drive_type',
        'drive_quantity': 'drive_quantity',
        'policy_type_id': 'policy_type_id',
        'description': 'description'
    }

    def __init__(self, name=None, drive_type=None, drive_quantity=None, policy_type_id=None, description=None, _configuration=None):  # noqa: E501
        """CreateStoragePolicyZios - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._drive_type = None
        self._drive_quantity = None
        self._policy_type_id = None
        self._description = None
        self.discriminator = None

        self.name = name
        self.drive_type = drive_type
        self.drive_quantity = drive_quantity
        self.policy_type_id = policy_type_id
        if description is not None:
            self.description = description

    @property
    def name(self):
        """Gets the name of this CreateStoragePolicyZios.  # noqa: E501


        :return: The name of this CreateStoragePolicyZios.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateStoragePolicyZios.


        :param name: The name of this CreateStoragePolicyZios.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def drive_type(self):
        """Gets the drive_type of this CreateStoragePolicyZios.  # noqa: E501


        :return: The drive_type of this CreateStoragePolicyZios.  # noqa: E501
        :rtype: str
        """
        return self._drive_type

    @drive_type.setter
    def drive_type(self, drive_type):
        """Sets the drive_type of this CreateStoragePolicyZios.


        :param drive_type: The drive_type of this CreateStoragePolicyZios.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and drive_type is None:
            raise ValueError("Invalid value for `drive_type`, must not be `None`")  # noqa: E501

        self._drive_type = drive_type

    @property
    def drive_quantity(self):
        """Gets the drive_quantity of this CreateStoragePolicyZios.  # noqa: E501


        :return: The drive_quantity of this CreateStoragePolicyZios.  # noqa: E501
        :rtype: int
        """
        return self._drive_quantity

    @drive_quantity.setter
    def drive_quantity(self, drive_quantity):
        """Sets the drive_quantity of this CreateStoragePolicyZios.


        :param drive_quantity: The drive_quantity of this CreateStoragePolicyZios.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and drive_quantity is None:
            raise ValueError("Invalid value for `drive_quantity`, must not be `None`")  # noqa: E501

        self._drive_quantity = drive_quantity

    @property
    def policy_type_id(self):
        """Gets the policy_type_id of this CreateStoragePolicyZios.  # noqa: E501


        :return: The policy_type_id of this CreateStoragePolicyZios.  # noqa: E501
        :rtype: int
        """
        return self._policy_type_id

    @policy_type_id.setter
    def policy_type_id(self, policy_type_id):
        """Sets the policy_type_id of this CreateStoragePolicyZios.


        :param policy_type_id: The policy_type_id of this CreateStoragePolicyZios.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and policy_type_id is None:
            raise ValueError("Invalid value for `policy_type_id`, must not be `None`")  # noqa: E501

        self._policy_type_id = policy_type_id

    @property
    def description(self):
        """Gets the description of this CreateStoragePolicyZios.  # noqa: E501


        :return: The description of this CreateStoragePolicyZios.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CreateStoragePolicyZios.


        :param description: The description of this CreateStoragePolicyZios.  # noqa: E501
        :type: str
        """

        self._description = description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateStoragePolicyZios, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateStoragePolicyZios):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateStoragePolicyZios):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class InlineResponse20091Vpsas(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'name': 'str',
        'internal_name': 'str',
        'user': 'str',
        'cloud_user_internal_id': 'int',
        'status': 'str',
        'redundancy_status': 'str',
        'management_address_ipv6': 'str',
        'management_address_netmask': 'str',
        'engine_type': 'str',
        'app_engine_type': 'str',
        'drives': 'int',
        'cache': 'int',
        'image': 'str',
        'management_address': 'str',
        'public_ip': 'str',
        'public_ip_netmask': 'str',
        'network_configuration': 'InlineResponse20091NetworkConfiguration',
        'active_vc_index': 'int',
        'fibre_channel_details': 'object',
        'storage_type': 'str',
        'data_reduction_bundle': 'bool',
        'uuid': 'str',
        'flc_enabled': 'bool',
        'iscsi_dual_target': 'bool',
        'snmp_engine_id': 'str',
        'created_at': 'str',
        'updated_at': 'str',
        'used_by_volumes_capacity': 'str',
        'effective_capacity': 'str',
        'provisioned_capacity': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'internal_name': 'internal_name',
        'user': 'user',
        'cloud_user_internal_id': 'cloud_user_internal_id',
        'status': 'status',
        'redundancy_status': 'redundancy_status',
        'management_address_ipv6': 'management_address_ipv6',
        'management_address_netmask': 'management_address_netmask',
        'engine_type': 'engine_type',
        'app_engine_type': 'app_engine_type',
        'drives': 'drives',
        'cache': 'cache',
        'image': 'image',
        'management_address': 'management_address',
        'public_ip': 'public_ip',
        'public_ip_netmask': 'public_ip_netmask',
        'network_configuration': 'network_configuration',
        'active_vc_index': 'active_vc_index',
        'fibre_channel_details': 'fibre_channel_details',
        'storage_type': 'storage_type',
        'data_reduction_bundle': 'data_reduction_bundle',
        'uuid': 'uuid',
        'flc_enabled': 'flc_enabled',
        'iscsi_dual_target': 'iscsi_dual_target',
        'snmp_engine_id': 'snmp_engine_id',
        'created_at': 'created_at',
        'updated_at': 'updated_at',
        'used_by_volumes_capacity': 'used_by_volumes_capacity',
        'effective_capacity': 'effective_capacity',
        'provisioned_capacity': 'provisioned_capacity'
    }

    def __init__(self, id=None, name=None, internal_name=None, user=None, cloud_user_internal_id=None, status=None, redundancy_status=None, management_address_ipv6=None, management_address_netmask=None, engine_type=None, app_engine_type=None, drives=None, cache=None, image=None, management_address=None, public_ip=None, public_ip_netmask=None, network_configuration=None, active_vc_index=None, fibre_channel_details=None, storage_type=None, data_reduction_bundle=None, uuid=None, flc_enabled=None, iscsi_dual_target=None, snmp_engine_id=None, created_at=None, updated_at=None, used_by_volumes_capacity=None, effective_capacity=None, provisioned_capacity=None, _configuration=None):  # noqa: E501
        """InlineResponse20091Vpsas - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._name = None
        self._internal_name = None
        self._user = None
        self._cloud_user_internal_id = None
        self._status = None
        self._redundancy_status = None
        self._management_address_ipv6 = None
        self._management_address_netmask = None
        self._engine_type = None
        self._app_engine_type = None
        self._drives = None
        self._cache = None
        self._image = None
        self._management_address = None
        self._public_ip = None
        self._public_ip_netmask = None
        self._network_configuration = None
        self._active_vc_index = None
        self._fibre_channel_details = None
        self._storage_type = None
        self._data_reduction_bundle = None
        self._uuid = None
        self._flc_enabled = None
        self._iscsi_dual_target = None
        self._snmp_engine_id = None
        self._created_at = None
        self._updated_at = None
        self._used_by_volumes_capacity = None
        self._effective_capacity = None
        self._provisioned_capacity = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if internal_name is not None:
            self.internal_name = internal_name
        if user is not None:
            self.user = user
        if cloud_user_internal_id is not None:
            self.cloud_user_internal_id = cloud_user_internal_id
        if status is not None:
            self.status = status
        if redundancy_status is not None:
            self.redundancy_status = redundancy_status
        if management_address_ipv6 is not None:
            self.management_address_ipv6 = management_address_ipv6
        if management_address_netmask is not None:
            self.management_address_netmask = management_address_netmask
        if engine_type is not None:
            self.engine_type = engine_type
        if app_engine_type is not None:
            self.app_engine_type = app_engine_type
        if drives is not None:
            self.drives = drives
        if cache is not None:
            self.cache = cache
        if image is not None:
            self.image = image
        if management_address is not None:
            self.management_address = management_address
        if public_ip is not None:
            self.public_ip = public_ip
        if public_ip_netmask is not None:
            self.public_ip_netmask = public_ip_netmask
        if network_configuration is not None:
            self.network_configuration = network_configuration
        if active_vc_index is not None:
            self.active_vc_index = active_vc_index
        if fibre_channel_details is not None:
            self.fibre_channel_details = fibre_channel_details
        if storage_type is not None:
            self.storage_type = storage_type
        if data_reduction_bundle is not None:
            self.data_reduction_bundle = data_reduction_bundle
        if uuid is not None:
            self.uuid = uuid
        if flc_enabled is not None:
            self.flc_enabled = flc_enabled
        if iscsi_dual_target is not None:
            self.iscsi_dual_target = iscsi_dual_target
        if snmp_engine_id is not None:
            self.snmp_engine_id = snmp_engine_id
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
        if used_by_volumes_capacity is not None:
            self.used_by_volumes_capacity = used_by_volumes_capacity
        if effective_capacity is not None:
            self.effective_capacity = effective_capacity
        if provisioned_capacity is not None:
            self.provisioned_capacity = provisioned_capacity

    @property
    def id(self):
        """Gets the id of this InlineResponse20091Vpsas.  # noqa: E501


        :return: The id of this InlineResponse20091Vpsas.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InlineResponse20091Vpsas.


        :param id: The id of this InlineResponse20091Vpsas.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this InlineResponse20091Vpsas.  # noqa: E501


        :return: The name of this InlineResponse20091Vpsas.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse20091Vpsas.


        :param name: The name of this InlineResponse20091Vpsas.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def internal_name(self):
        """Gets the internal_name of this InlineResponse20091Vpsas.  # noqa: E501


        :return: The internal_name of this InlineResponse20091Vpsas.  # noqa: E501
        :rtype: str
        """
        return self._internal_name

    @internal_name.setter
    def internal_name(self, internal_name):
        """Sets the internal_name of this InlineResponse20091Vpsas.


        :param internal_name: The internal_name of this InlineResponse20091Vpsas.  # noqa: E501
        :type: str
        """

        self._internal_name = internal_name

    @property
    def user(self):
        """Gets the user of this InlineResponse20091Vpsas.  # noqa: E501


        :return: The user of this InlineResponse20091Vpsas.  # noqa: E501
        :rtype: str
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this InlineResponse20091Vpsas.


        :param user: The user of this InlineResponse20091Vpsas.  # noqa: E501
        :type: str
        """

        self._user = user

    @property
    def cloud_user_internal_id(self):
        """Gets the cloud_user_internal_id of this InlineResponse20091Vpsas.  # noqa: E501


        :return: The cloud_user_internal_id of this InlineResponse20091Vpsas.  # noqa: E501
        :rtype: int
        """
        return self._cloud_user_internal_id

    @cloud_user_internal_id.setter
    def cloud_user_internal_id(self, cloud_user_internal_id):
        """Sets the cloud_user_internal_id of this InlineResponse20091Vpsas.


        :param cloud_user_internal_id: The cloud_user_internal_id of this InlineResponse20091Vpsas.  # noqa: E501
        :type: int
        """

        self._cloud_user_internal_id = cloud_user_internal_id

    @property
    def status(self):
        """Gets the status of this InlineResponse20091Vpsas.  # noqa: E501


        :return: The status of this InlineResponse20091Vpsas.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InlineResponse20091Vpsas.


        :param status: The status of this InlineResponse20091Vpsas.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def redundancy_status(self):
        """Gets the redundancy_status of this InlineResponse20091Vpsas.  # noqa: E501


        :return: The redundancy_status of this InlineResponse20091Vpsas.  # noqa: E501
        :rtype: str
        """
        return self._redundancy_status

    @redundancy_status.setter
    def redundancy_status(self, redundancy_status):
        """Sets the redundancy_status of this InlineResponse20091Vpsas.


        :param redundancy_status: The redundancy_status of this InlineResponse20091Vpsas.  # noqa: E501
        :type: str
        """

        self._redundancy_status = redundancy_status

    @property
    def management_address_ipv6(self):
        """Gets the management_address_ipv6 of this InlineResponse20091Vpsas.  # noqa: E501


        :return: The management_address_ipv6 of this InlineResponse20091Vpsas.  # noqa: E501
        :rtype: str
        """
        return self._management_address_ipv6

    @management_address_ipv6.setter
    def management_address_ipv6(self, management_address_ipv6):
        """Sets the management_address_ipv6 of this InlineResponse20091Vpsas.


        :param management_address_ipv6: The management_address_ipv6 of this InlineResponse20091Vpsas.  # noqa: E501
        :type: str
        """

        self._management_address_ipv6 = management_address_ipv6

    @property
    def management_address_netmask(self):
        """Gets the management_address_netmask of this InlineResponse20091Vpsas.  # noqa: E501


        :return: The management_address_netmask of this InlineResponse20091Vpsas.  # noqa: E501
        :rtype: str
        """
        return self._management_address_netmask

    @management_address_netmask.setter
    def management_address_netmask(self, management_address_netmask):
        """Sets the management_address_netmask of this InlineResponse20091Vpsas.


        :param management_address_netmask: The management_address_netmask of this InlineResponse20091Vpsas.  # noqa: E501
        :type: str
        """

        self._management_address_netmask = management_address_netmask

    @property
    def engine_type(self):
        """Gets the engine_type of this InlineResponse20091Vpsas.  # noqa: E501


        :return: The engine_type of this InlineResponse20091Vpsas.  # noqa: E501
        :rtype: str
        """
        return self._engine_type

    @engine_type.setter
    def engine_type(self, engine_type):
        """Sets the engine_type of this InlineResponse20091Vpsas.


        :param engine_type: The engine_type of this InlineResponse20091Vpsas.  # noqa: E501
        :type: str
        """

        self._engine_type = engine_type

    @property
    def app_engine_type(self):
        """Gets the app_engine_type of this InlineResponse20091Vpsas.  # noqa: E501


        :return: The app_engine_type of this InlineResponse20091Vpsas.  # noqa: E501
        :rtype: str
        """
        return self._app_engine_type

    @app_engine_type.setter
    def app_engine_type(self, app_engine_type):
        """Sets the app_engine_type of this InlineResponse20091Vpsas.


        :param app_engine_type: The app_engine_type of this InlineResponse20091Vpsas.  # noqa: E501
        :type: str
        """

        self._app_engine_type = app_engine_type

    @property
    def drives(self):
        """Gets the drives of this InlineResponse20091Vpsas.  # noqa: E501


        :return: The drives of this InlineResponse20091Vpsas.  # noqa: E501
        :rtype: int
        """
        return self._drives

    @drives.setter
    def drives(self, drives):
        """Sets the drives of this InlineResponse20091Vpsas.


        :param drives: The drives of this InlineResponse20091Vpsas.  # noqa: E501
        :type: int
        """

        self._drives = drives

    @property
    def cache(self):
        """Gets the cache of this InlineResponse20091Vpsas.  # noqa: E501


        :return: The cache of this InlineResponse20091Vpsas.  # noqa: E501
        :rtype: int
        """
        return self._cache

    @cache.setter
    def cache(self, cache):
        """Sets the cache of this InlineResponse20091Vpsas.


        :param cache: The cache of this InlineResponse20091Vpsas.  # noqa: E501
        :type: int
        """

        self._cache = cache

    @property
    def image(self):
        """Gets the image of this InlineResponse20091Vpsas.  # noqa: E501


        :return: The image of this InlineResponse20091Vpsas.  # noqa: E501
        :rtype: str
        """
        return self._image

    @image.setter
    def image(self, image):
        """Sets the image of this InlineResponse20091Vpsas.


        :param image: The image of this InlineResponse20091Vpsas.  # noqa: E501
        :type: str
        """

        self._image = image

    @property
    def management_address(self):
        """Gets the management_address of this InlineResponse20091Vpsas.  # noqa: E501


        :return: The management_address of this InlineResponse20091Vpsas.  # noqa: E501
        :rtype: str
        """
        return self._management_address

    @management_address.setter
    def management_address(self, management_address):
        """Sets the management_address of this InlineResponse20091Vpsas.


        :param management_address: The management_address of this InlineResponse20091Vpsas.  # noqa: E501
        :type: str
        """

        self._management_address = management_address

    @property
    def public_ip(self):
        """Gets the public_ip of this InlineResponse20091Vpsas.  # noqa: E501


        :return: The public_ip of this InlineResponse20091Vpsas.  # noqa: E501
        :rtype: str
        """
        return self._public_ip

    @public_ip.setter
    def public_ip(self, public_ip):
        """Sets the public_ip of this InlineResponse20091Vpsas.


        :param public_ip: The public_ip of this InlineResponse20091Vpsas.  # noqa: E501
        :type: str
        """

        self._public_ip = public_ip

    @property
    def public_ip_netmask(self):
        """Gets the public_ip_netmask of this InlineResponse20091Vpsas.  # noqa: E501


        :return: The public_ip_netmask of this InlineResponse20091Vpsas.  # noqa: E501
        :rtype: str
        """
        return self._public_ip_netmask

    @public_ip_netmask.setter
    def public_ip_netmask(self, public_ip_netmask):
        """Sets the public_ip_netmask of this InlineResponse20091Vpsas.


        :param public_ip_netmask: The public_ip_netmask of this InlineResponse20091Vpsas.  # noqa: E501
        :type: str
        """

        self._public_ip_netmask = public_ip_netmask

    @property
    def network_configuration(self):
        """Gets the network_configuration of this InlineResponse20091Vpsas.  # noqa: E501


        :return: The network_configuration of this InlineResponse20091Vpsas.  # noqa: E501
        :rtype: InlineResponse20091NetworkConfiguration
        """
        return self._network_configuration

    @network_configuration.setter
    def network_configuration(self, network_configuration):
        """Sets the network_configuration of this InlineResponse20091Vpsas.


        :param network_configuration: The network_configuration of this InlineResponse20091Vpsas.  # noqa: E501
        :type: InlineResponse20091NetworkConfiguration
        """

        self._network_configuration = network_configuration

    @property
    def active_vc_index(self):
        """Gets the active_vc_index of this InlineResponse20091Vpsas.  # noqa: E501


        :return: The active_vc_index of this InlineResponse20091Vpsas.  # noqa: E501
        :rtype: int
        """
        return self._active_vc_index

    @active_vc_index.setter
    def active_vc_index(self, active_vc_index):
        """Sets the active_vc_index of this InlineResponse20091Vpsas.


        :param active_vc_index: The active_vc_index of this InlineResponse20091Vpsas.  # noqa: E501
        :type: int
        """

        self._active_vc_index = active_vc_index

    @property
    def fibre_channel_details(self):
        """Gets the fibre_channel_details of this InlineResponse20091Vpsas.  # noqa: E501


        :return: The fibre_channel_details of this InlineResponse20091Vpsas.  # noqa: E501
        :rtype: object
        """
        return self._fibre_channel_details

    @fibre_channel_details.setter
    def fibre_channel_details(self, fibre_channel_details):
        """Sets the fibre_channel_details of this InlineResponse20091Vpsas.


        :param fibre_channel_details: The fibre_channel_details of this InlineResponse20091Vpsas.  # noqa: E501
        :type: object
        """

        self._fibre_channel_details = fibre_channel_details

    @property
    def storage_type(self):
        """Gets the storage_type of this InlineResponse20091Vpsas.  # noqa: E501


        :return: The storage_type of this InlineResponse20091Vpsas.  # noqa: E501
        :rtype: str
        """
        return self._storage_type

    @storage_type.setter
    def storage_type(self, storage_type):
        """Sets the storage_type of this InlineResponse20091Vpsas.


        :param storage_type: The storage_type of this InlineResponse20091Vpsas.  # noqa: E501
        :type: str
        """

        self._storage_type = storage_type

    @property
    def data_reduction_bundle(self):
        """Gets the data_reduction_bundle of this InlineResponse20091Vpsas.  # noqa: E501


        :return: The data_reduction_bundle of this InlineResponse20091Vpsas.  # noqa: E501
        :rtype: bool
        """
        return self._data_reduction_bundle

    @data_reduction_bundle.setter
    def data_reduction_bundle(self, data_reduction_bundle):
        """Sets the data_reduction_bundle of this InlineResponse20091Vpsas.


        :param data_reduction_bundle: The data_reduction_bundle of this InlineResponse20091Vpsas.  # noqa: E501
        :type: bool
        """

        self._data_reduction_bundle = data_reduction_bundle

    @property
    def uuid(self):
        """Gets the uuid of this InlineResponse20091Vpsas.  # noqa: E501


        :return: The uuid of this InlineResponse20091Vpsas.  # noqa: E501
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """Sets the uuid of this InlineResponse20091Vpsas.


        :param uuid: The uuid of this InlineResponse20091Vpsas.  # noqa: E501
        :type: str
        """

        self._uuid = uuid

    @property
    def flc_enabled(self):
        """Gets the flc_enabled of this InlineResponse20091Vpsas.  # noqa: E501


        :return: The flc_enabled of this InlineResponse20091Vpsas.  # noqa: E501
        :rtype: bool
        """
        return self._flc_enabled

    @flc_enabled.setter
    def flc_enabled(self, flc_enabled):
        """Sets the flc_enabled of this InlineResponse20091Vpsas.


        :param flc_enabled: The flc_enabled of this InlineResponse20091Vpsas.  # noqa: E501
        :type: bool
        """

        self._flc_enabled = flc_enabled

    @property
    def iscsi_dual_target(self):
        """Gets the iscsi_dual_target of this InlineResponse20091Vpsas.  # noqa: E501


        :return: The iscsi_dual_target of this InlineResponse20091Vpsas.  # noqa: E501
        :rtype: bool
        """
        return self._iscsi_dual_target

    @iscsi_dual_target.setter
    def iscsi_dual_target(self, iscsi_dual_target):
        """Sets the iscsi_dual_target of this InlineResponse20091Vpsas.


        :param iscsi_dual_target: The iscsi_dual_target of this InlineResponse20091Vpsas.  # noqa: E501
        :type: bool
        """

        self._iscsi_dual_target = iscsi_dual_target

    @property
    def snmp_engine_id(self):
        """Gets the snmp_engine_id of this InlineResponse20091Vpsas.  # noqa: E501


        :return: The snmp_engine_id of this InlineResponse20091Vpsas.  # noqa: E501
        :rtype: str
        """
        return self._snmp_engine_id

    @snmp_engine_id.setter
    def snmp_engine_id(self, snmp_engine_id):
        """Sets the snmp_engine_id of this InlineResponse20091Vpsas.


        :param snmp_engine_id: The snmp_engine_id of this InlineResponse20091Vpsas.  # noqa: E501
        :type: str
        """

        self._snmp_engine_id = snmp_engine_id

    @property
    def created_at(self):
        """Gets the created_at of this InlineResponse20091Vpsas.  # noqa: E501


        :return: The created_at of this InlineResponse20091Vpsas.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InlineResponse20091Vpsas.


        :param created_at: The created_at of this InlineResponse20091Vpsas.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this InlineResponse20091Vpsas.  # noqa: E501


        :return: The updated_at of this InlineResponse20091Vpsas.  # noqa: E501
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this InlineResponse20091Vpsas.


        :param updated_at: The updated_at of this InlineResponse20091Vpsas.  # noqa: E501
        :type: str
        """

        self._updated_at = updated_at

    @property
    def used_by_volumes_capacity(self):
        """Gets the used_by_volumes_capacity of this InlineResponse20091Vpsas.  # noqa: E501


        :return: The used_by_volumes_capacity of this InlineResponse20091Vpsas.  # noqa: E501
        :rtype: str
        """
        return self._used_by_volumes_capacity

    @used_by_volumes_capacity.setter
    def used_by_volumes_capacity(self, used_by_volumes_capacity):
        """Sets the used_by_volumes_capacity of this InlineResponse20091Vpsas.


        :param used_by_volumes_capacity: The used_by_volumes_capacity of this InlineResponse20091Vpsas.  # noqa: E501
        :type: str
        """

        self._used_by_volumes_capacity = used_by_volumes_capacity

    @property
    def effective_capacity(self):
        """Gets the effective_capacity of this InlineResponse20091Vpsas.  # noqa: E501


        :return: The effective_capacity of this InlineResponse20091Vpsas.  # noqa: E501
        :rtype: str
        """
        return self._effective_capacity

    @effective_capacity.setter
    def effective_capacity(self, effective_capacity):
        """Sets the effective_capacity of this InlineResponse20091Vpsas.


        :param effective_capacity: The effective_capacity of this InlineResponse20091Vpsas.  # noqa: E501
        :type: str
        """

        self._effective_capacity = effective_capacity

    @property
    def provisioned_capacity(self):
        """Gets the provisioned_capacity of this InlineResponse20091Vpsas.  # noqa: E501


        :return: The provisioned_capacity of this InlineResponse20091Vpsas.  # noqa: E501
        :rtype: str
        """
        return self._provisioned_capacity

    @provisioned_capacity.setter
    def provisioned_capacity(self, provisioned_capacity):
        """Sets the provisioned_capacity of this InlineResponse20091Vpsas.


        :param provisioned_capacity: The provisioned_capacity of this InlineResponse20091Vpsas.  # noqa: E501
        :type: str
        """

        self._provisioned_capacity = provisioned_capacity

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20091Vpsas, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20091Vpsas):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20091Vpsas):
            return True

        return self.to_dict() != other.to_dict()
